/*
 Descrio: Procedure para consulta de CST por imposto para nfe
*/

IF EXISTS (SELECT * 
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CONSULTA_CST_NFE' AND
	         TYPE = 'P'                  AND
	         U.UID = O.UID               AND
	         U.NAME = USER)
DROP PROCEDURE CONSULTA_CST_NFE
GO

CREATE PROCEDURE CONSULTA_CST_NFE
   @P_ENTSAICST     VARCHAR(01),
   @P_EMPRESA       VARCHAR(02),
   @P_CDARVPROD     VARCHAR(20),
   @P_INSCESTA      VARCHAR(16),
   @P_TIPOOPER      VARCHAR(02),
   @P_CDGRUPOFISC   VARCHAR(02),
   @P_CDIMPOSTO     VARCHAR(02),
   @P_IDCSTINTEREST VARCHAR(01),
   @P_IDCSTINTERNA  VARCHAR(01),
   @P_FILIAL        VARCHAR(04),
   @P_LANCTONF      VARCHAR(10),
   @P_CDCLIENTE     VARCHAR(21),
   @P_IDORIGEMPROD  VARCHAR(01)  = 'N',
   @P_CDSITTRIBTMP  VARCHAR(02) OUTPUT,
   @P_IDMODBCNFE    VARCHAR(01) OUTPUT,
   @P_IDMODBCSTNFE  VARCHAR(01) OUTPUT,
   @P_CDTPCRPICOSTNFE VARCHAR(03) OUTPUT,
   @P_CDNATUBCPCSTNFE VARCHAR(02) OUTPUT,
   @P_IDMOTIDESSTNFE  VARCHAR(01) OUTPUT
AS
   DECLARE @V_SEQUENCIA     VARCHAR(02);
   DECLARE @V_CST1DIGT      VARCHAR(1);
   DECLARE @V_CDARVPROD     VARCHAR(20);
   DECLARE @V_ORIGDESTOP    VARCHAR(1);
   DECLARE @V_EMPRESA       VARCHAR(02);
   DECLARE @V_INSCESTA      VARCHAR(16);
   DECLARE @V_CONTADOR      INTEGER;
   DECLARE @V_CONTINTEREST  INTEGER;
   DECLARE @V_CONTINTERNA   INTEGER;
   DECLARE @V_CDSITUTRIBNFE VARCHAR(02);
   DECLARE @V_IDMODBCNFE    VARCHAR(01);
   DECLARE @V_IDMODBCSTNFE  VARCHAR(01);
   DECLARE @V_CDTPCRPICOSTNFE  VARCHAR(03);
   DECLARE @V_CDNATUBCPCSTNFE  VARCHAR(02);
   DECLARE @V_IDMOTIDESSTNFE   VARCHAR(01);
   /*VARIVEIS DO CURSOR C_CST*/
   DECLARE @V_CDSITUTRIB    VARCHAR(02);
   DECLARE @V_DSMENSCST     VARCHAR(120);
   DECLARE @V_NRINCIDCST    VARCHAR(10);

   DECLARE @V_INIVALID       DATETIME;
   DECLARE @V_PAISORIG       VARCHAR(04); -- Pais de origem (utiliza UF de Origem)
   DECLARE @V_ESTAORIG       VARCHAR(02); -- Estado de origem (utiliza UF de Origem)
   DECLARE @V_MUNIORIG       VARCHAR(04); -- Municipio de origem (utiliza municipio)
   DECLARE @V_PAISDEST       VARCHAR(04);
   DECLARE @V_ESTADEST       VARCHAR(02);
   DECLARE @V_MUNIDEST       VARCHAR(04);
   DECLARE @V_IDENDCFOP      VARCHAR(01);
   DECLARE @V_IDORIGDESTNF   VARCHAR(01);
   DECLARE @V_CDCLIENTE      VARCHAR(21);
   DECLARE @V_CDORIGDESTNF   VARCHAR(21);
   DECLARE @V_IDENDEMIS      VARCHAR(01);
   DECLARE @V_CDEMPRESA      VARCHAR(02);
   DECLARE @V_CDINSCESTA     VARCHAR(16);
   DECLARE @V_CDFILIRECE     VARCHAR(04);
   DECLARE @V_CDFORNECED     VARCHAR(21);
   DECLARE @V_CDFILIEMIT     VARCHAR(04);
   DECLARE @V_VRITEM         DOUBLE PRECISION;
   DECLARE @V_CDREGRA        VARCHAR(10);
   DECLARE @V_CDGRUPOFISC    VARCHAR(03);
   /*VARIVEIS DO CURSOR C_REGRA*/
   DECLARE @V_REGRA_CDREGRAFISC     VARCHAR(10);
   DECLARE @V_REGRA_CDSITUTRIB      VARCHAR(02);
   DECLARE @V_REGRA_IDMODBCNFE      VARCHAR(01);
   DECLARE @V_REGRA_IDMODBCSTNFE    VARCHAR(01);
   DECLARE @V_REGRA_CDTPCRPICOSTNFE VARCHAR(03);
   DECLARE @V_REGRA_CDNATUBCPCSTNFE VARCHAR(02);
   DECLARE @V_REGRA_IDMOTIDESSTNFE  VARCHAR(01);

   DECLARE @V_IDNFPRESTSERV         VARCHAR(01);

   DECLARE @V_IDPRESENCIAL          VARCHAR(01);
BEGIN
   SET @V_CDSITUTRIBNFE   = NULL;
   SET @V_IDMODBCNFE      = NULL;
   SET @V_IDMODBCSTNFE    = NULL;
   SET @V_CDTPCRPICOSTNFE = NULL;
   SET @V_CDNATUBCPCSTNFE = NULL;
   SET @V_IDMOTIDESSTNFE  = NULL;
   SET @V_SEQUENCIA       = '01';
   SET @V_CONTINTEREST    = 0;
   SET @V_CONTINTERNA     = 0;
   SET @V_CONTADOR        = 0;

   SELECT @V_INIVALID = MAX(N.DTENTRSAID), 
          @V_CDFILIEMIT = MAX(N.CDFILIEMIT), 
          @V_IDORIGDESTNF = MAX(N.IDORIGDESTNF), 
          @V_CDCLIENTE = MAX(N.CDCLIENTE),
          @V_CDFILIRECE = MAX(N.CDFILIRECE), 
          @V_CDFORNECED = MAX(N.CDFORNECED), 
          @V_VRITEM = (MAX(IT.VRTOTAITEM) - MAX(IT.VRDESCITEM)),
          @V_IDPRESENCIAL = ISNULL(MAX(N.IDPRESENCIAL), '9')
     FROM NOTAFISCAL N, ITEMPRODUTO IT, PRODUTO P
    WHERE N.CDFILIAL = @P_FILIAL
      AND N.NRLANCTONF = @P_LANCTONF
      AND N.CDFILIAL = IT.CDFILIAL
      AND N.NRLANCTONF = IT.NRLANCTONF
      AND IT.CDPRODUTO = P.CDPRODUTO
      AND P.CDARVPROD  = @P_CDARVPROD;

   IF @P_CDCLIENTE IS NOT NULL BEGIN
      SET @V_CDCLIENTE = @P_CDCLIENTE;
   END;

   IF (@P_ENTSAICST = 'S') BEGIN
      SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPFIL),'I'), @V_CDEMPRESA = MAX(CDEMPRESA), @V_CDINSCESTA = MAX(CDINSCESTA)
        FROM FILIAL
       WHERE (CDFILIAL = @V_CDFILIEMIT);

      IF (@V_IDENDCFOP = 'I') BEGIN
         SELECT @V_PAISORIG = MAX(CDPAIS), @V_ESTAORIG = MAX(SGESTADO), @V_MUNIORIG = MAX(CDMUNICIPIO)
           FROM INSCRESTAD
          WHERE CDEMPRESA  = @P_EMPRESA
            AND CDINSCESTA = @P_INSCESTA;
      END
      ELSE BEGIN
         SELECT @V_PAISORIG = MAX(CDPAIS), @V_ESTAORIG = MAX(SGESTADO), @V_MUNIORIG = MAX(CDMUNICIPIO)
           FROM ENDEFILI
          WHERE (CDFILIAL     = @V_CDFILIEMIT)
            AND (IDTPENDEFILI = @V_IDENDCFOP);
      END;

      /*DESTINATRIO-REMETENTE DA NOTA*/
      IF (@V_IDORIGDESTNF IS NULL) BEGIN
         SELECT @V_ORIGDESTOP = MAX(IDORIGDESTOP)
           FROM TIPOOPERAC
          WHERE IDENTRSAIDOP = 'S'
            AND CDTIPOOPER   = @P_TIPOOPER;
      END
      ELSE BEGIN
         SET @V_ORIGDESTOP = @V_IDORIGDESTNF;
      END;

      IF (@V_ORIGDESTOP = 'L') BEGIN /*DESTINATARIO -> FILIAL */
         SET @V_CDORIGDESTNF = @V_CDFILIRECE;

         SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPFIL),'I'), @V_IDENDEMIS = ISNULL(MAX(IDENDEMISFIL),'I'), @V_CDEMPRESA = MAX(CDEMPRESA), @V_CDINSCESTA = MAX(CDINSCESTA)
           FROM FILIAL
          WHERE (CDFILIAL = @V_CDFILIRECE);

         IF (@V_IDENDEMIS = 'I') BEGIN
            SELECT @V_PAISDEST = MAX(CDPAIS), @V_ESTADEST = MAX(SGESTADO), @V_MUNIDEST = MAX(CDMUNICIPIO)
              FROM INSCRESTAD
             WHERE CDEMPRESA  = @V_CDEMPRESA
               AND CDINSCESTA = @V_CDINSCESTA;
         END
         ELSE BEGIN
            SELECT @V_PAISDEST = MAX(CDPAIS), @V_ESTADEST = MAX(SGESTADO), @V_MUNIDEST = MAX(CDMUNICIPIO)
              FROM ENDEFILI
             WHERE CDFILIAL     = @V_CDFILIRECE
               AND IDTPENDEFILI = @V_IDENDEMIS;
         END;
      END
      ELSE IF (@V_ORIGDESTOP = 'F') BEGIN /*DESTINATARIO -> FORNECEDOR */
         SET @V_CDORIGDESTNF = @V_CDFORNECED;

         SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPFOR),'P'), @V_IDENDEMIS = ISNULL(MAX(IDENDEMISFOR),'P')
           FROM FORNECEDOR
          WHERE (CDFORNECED = @V_CDORIGDESTNF);


         SELECT @V_PAISDEST = MAX(CDPAIS), @V_ESTADEST = MAX(SGESTADO), @V_MUNIDEST = MAX(CDMUNICIPIO)
           FROM ENDEFORN
          WHERE (CDFORNECED   = @V_CDORIGDESTNF)
            AND (IDTPENDEFORN = @V_IDENDEMIS);
      END
      ELSE BEGIN/*DESTINATARIO -> CLIENTE(DEFAULT) */
         SET @V_CDORIGDESTNF = @V_CDCLIENTE;

         SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPCLI),'P'), @V_IDENDEMIS = ISNULL(MAX(IDENDEMISCLI),'P')
           FROM CLIENTE
          WHERE (CDCLIENTE = @V_CDORIGDESTNF);

         IF (@V_IDENDCFOP = 'I') BEGIN
            SELECT @V_PAISDEST = MAX(CDPAIS), @V_ESTADEST = MAX(SGESTADO), @V_MUNIDEST = MAX(CDMUNICIPIO)
              FROM INSCRESTAD
             WHERE CDEMPRESA  = @P_EMPRESA
               AND CDINSCESTA = @P_INSCESTA;
         END
         ELSE BEGIN
            SELECT @V_PAISDEST = MAX(CDPAIS), @V_ESTADEST = MAX(SGESTADO), @V_MUNIDEST = MAX(CDMUNICIPIO)
              FROM ENDECLIE
             WHERE (CDCLIENTE    = @V_CDORIGDESTNF)
               AND (IDTPENDECLIE = @V_IDENDEMIS);
         END;
      END;
      /*
      QUANDO A OPERAO DA NOTA FISCAL FOR PRESENCIAL O SISTEMA USAR COMO ENDEREO
      DE DESTINO O MESMO ENDEREO DA ORIGEM. EST CONDIO FOI NECESSRIA PARA ATENDER 
      A NOTA TCNICA 2015/003
      */
      IF @V_IDPRESENCIAL = '1' BEGIN
         SET @V_PAISDEST = @V_PAISORIG;
         SET @V_ESTADEST = @V_ESTAORIG;
         SET @V_MUNIDEST = @V_MUNIORIG;
      END;
   END;

   IF (@P_ENTSAICST = 'E') BEGIN
      SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPFIL),'I'), @V_CDEMPRESA = MAX(CDEMPRESA), @V_CDINSCESTA = MAX(CDINSCESTA)
        FROM FILIAL
       WHERE (CDFILIAL = @V_CDFILIRECE);

      SELECT @V_PAISDEST = MAX(CDPAIS), @V_ESTADEST = MAX(SGESTADO), @V_MUNIDEST = MAX(CDMUNICIPIO)
        FROM INSCRESTAD
       WHERE CDEMPRESA  = @P_EMPRESA
         AND CDINSCESTA = @P_INSCESTA;

      SELECT @V_IDNFPRESTSERV = ISNULL(MAX(IDNFPRESTSERV), 'N')
        FROM TIPOOPERAC
       WHERE IDENTRSAIDOP = 'E'
         AND CDTIPOOPER   = @P_TIPOOPER;

      IF (@V_IDNFPRESTSERV = 'S') BEGIN
         SELECT @V_PAISDEST = MAX(CDPAIS),
                @V_ESTADEST = MAX(SGESTADO),
                @V_MUNIDEST = MAX(CDMUNICIPIO)
           FROM ENDEFILI
          WHERE (CDFILIAL = @V_CDFILIRECE)
            AND (IDTPENDEFILI = 'P');
      END;

      /*DESTINATRIO-REMETENTE DA NOTA*/
      IF (@V_IDORIGDESTNF IS NULL) BEGIN
         SELECT @V_ORIGDESTOP = ISNULL(MAX(IDORIGDESTOP), 'F')
           FROM TIPOOPERAC
          WHERE IDENTRSAIDOP = 'E'
            AND CDTIPOOPER   = @P_TIPOOPER;
      END
      ELSE BEGIN
         SET @V_ORIGDESTOP = @V_IDORIGDESTNF;
      END;

      IF (@V_ORIGDESTOP = 'L') BEGIN /*DESTINATARIO -> FILIAL */
         SET @V_CDORIGDESTNF = @V_CDFILIEMIT;

         SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPFIL),'I'), @V_IDENDEMIS = ISNULL(MAX(IDENDEMISFIL),'I'), @V_CDEMPRESA = MAX(CDEMPRESA), @V_CDINSCESTA = MAX(CDINSCESTA)
           FROM FILIAL
          WHERE (CDFILIAL = @V_CDFILIEMIT);

         IF (@V_IDENDEMIS = 'I') BEGIN
            SELECT @V_PAISORIG = MAX(CDPAIS), @V_ESTAORIG = MAX(SGESTADO), @V_MUNIORIG = MAX(CDMUNICIPIO)
              FROM INSCRESTAD
             WHERE CDEMPRESA  = @V_CDEMPRESA
               AND CDINSCESTA = @V_CDINSCESTA;
         END
         ELSE BEGIN
            SELECT @V_PAISORIG = MAX(CDPAIS), @V_ESTAORIG = MAX(SGESTADO), @V_MUNIORIG = MAX(CDMUNICIPIO)
              FROM ENDEFILI
             WHERE CDFILIAL     = @V_CDFILIRECE
               AND IDTPENDEFILI = @V_IDENDEMIS;
         END;
      END
      ELSE IF (@V_ORIGDESTOP = 'F') BEGIN /*DESTINATARIO -> FORNECEDOR */
         SET @V_CDORIGDESTNF = @V_CDFORNECED;

         SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPFOR),'P'), @V_IDENDEMIS = ISNULL(MAX(IDENDEMISFOR),'P')
           FROM FORNECEDOR
          WHERE (CDFORNECED = @V_CDORIGDESTNF);


         SELECT @V_PAISORIG = MAX(CDPAIS), @V_ESTAORIG = MAX(SGESTADO), @V_MUNIORIG = MAX(CDMUNICIPIO)
           FROM ENDEFORN
          WHERE (CDFORNECED   = @V_CDORIGDESTNF)
            AND (IDTPENDEFORN = @V_IDENDEMIS);
      END
      ELSE BEGIN/*DESTINATARIO -> CLIENTE*/
         SET @V_CDORIGDESTNF = @V_CDCLIENTE;

         SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPCLI),'P'), @V_IDENDEMIS = ISNULL(MAX(IDENDEMISCLI),'P')
           FROM CLIENTE
          WHERE (CDCLIENTE = @V_CDORIGDESTNF);

         IF (@V_IDENDCFOP = 'I') BEGIN
            SELECT @V_PAISORIG = MAX(CDPAIS), @V_ESTAORIG = MAX(SGESTADO), @V_MUNIORIG = MAX(CDMUNICIPIO)
              FROM INSCRESTAD
             WHERE CDEMPRESA  = @P_EMPRESA
               AND CDINSCESTA = @P_INSCESTA;
         END
         ELSE BEGIN
            SELECT @V_PAISORIG = MAX(CDPAIS), @V_ESTAORIG = MAX(SGESTADO), @V_MUNIORIG = MAX(CDMUNICIPIO)
              FROM ENDECLIE
             WHERE (CDCLIENTE    = @V_CDORIGDESTNF)
               AND (IDTPENDECLIE = @V_IDENDEMIS);
         END;
      END;
   END;

   SET @V_CDREGRA = NULL;

   DECLARE C_REGRA CURSOR FOR
         SELECT CDREGRAFISC,     CDSITUTRIB,      IDMODBCNFE,     IDMODBCSTNFE,
                CDTPCRPICOSTNFE, CDNATUBCPCSTNFE, IDMOTIDESSTNFE
            FROM TEKNISA.CONSULTA_REGRA_FISCAL(@P_CDIMPOSTO, @P_EMPRESA, @P_CDGRUPOFISC, @P_ENTSAICST, @P_TIPOOPER, @P_INSCESTA, @P_CDARVPROD, @V_INIVALID,
                                               @V_PAISORIG, @V_ESTAORIG, @V_MUNIORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_VRITEM, 'N', @P_IDORIGEMPROD)
           WHERE VRALIQUOTA IS NOT NULL;

   OPEN C_REGRA;
   FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDREGRAFISC, @V_REGRA_CDSITUTRIB, @V_REGRA_IDMODBCNFE, @V_REGRA_IDMODBCSTNFE,
                                @V_REGRA_CDTPCRPICOSTNFE, @V_REGRA_CDNATUBCPCSTNFE, @V_REGRA_IDMOTIDESSTNFE;
   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_CDSITUTRIBNFE   = @V_REGRA_CDSITUTRIB;
      SET @V_IDMODBCNFE      = @V_REGRA_IDMODBCNFE;
      SET @V_IDMODBCSTNFE    = @V_REGRA_IDMODBCSTNFE;
      SET @V_CDTPCRPICOSTNFE = @V_REGRA_CDTPCRPICOSTNFE;
      SET @V_CDNATUBCPCSTNFE = @V_REGRA_CDNATUBCPCSTNFE;
      SET @V_CDREGRA         = @V_REGRA_CDREGRAFISC;
      SET @V_IDMOTIDESSTNFE  = @V_REGRA_IDMOTIDESSTNFE;
      FETCH NEXT FROM C_REGRA INTO @V_REGRA_CDREGRAFISC, @V_REGRA_CDSITUTRIB, @V_REGRA_IDMODBCNFE, @V_REGRA_IDMODBCSTNFE,
                                   @V_REGRA_CDTPCRPICOSTNFE, @V_REGRA_CDNATUBCPCSTNFE, @V_REGRA_IDMOTIDESSTNFE;
   END;
   CLOSE C_REGRA;
   DEALLOCATE C_REGRA;

   IF (@V_CDREGRA IS NULL) BEGIN
      IF (@P_IDCSTINTERNA = 'S') BEGIN
         IF @P_CDARVPROD IS NULL BEGIN
            SELECT @V_CONTINTERNA = COUNT(*)
              FROM CODSITUTRIB C
             WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                   (CDEMPRESA       = @P_EMPRESA)         AND
                   (CDTIPOOPER      = @P_TIPOOPER)        AND
                   (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                   (C.IDCSTINTEREST = 'N')                AND
                   (C.IDCSTINTERNA  = 'S')                AND
                   (C.CDPRODUTO IS NULL)
         END
         ELSE BEGIN
            SELECT @V_CONTINTERNA = COUNT(*)
              FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
             WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                   (CDEMPRESA       = @P_EMPRESA)         AND
                   (CDTIPOOPER      = @P_TIPOOPER)        AND
                   (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                   (C.IDCSTINTEREST = 'N')                AND
                   (C.IDCSTINTERNA  = 'S')                AND
                   (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);
         END;
         IF @V_CONTINTERNA > 0 BEGIN
            IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
               SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
               FROM   CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
               WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                      (CDEMPRESA       = @P_EMPRESA)         AND
                      (CDTIPOOPER      = @P_TIPOOPER)        AND
                      (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                      (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                      (C.IDCSTINTEREST = 'N')                AND
                      (C.IDCSTINTERNA  = 'S')                AND
                      (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD), @P_CDARVPROD) = 1);

               IF @V_CONTADOR > 0 BEGIN
                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                              FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                   LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                                              WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                     (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                     (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                     (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                     (C.IDCSTINTEREST = 'N')                AND
                                                     (C.IDCSTINTERNA  = 'S')                AND
                                                     (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                     (P.CDARVPROD     = @V_CDARVPROD);

                        OPEN C_CST;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                  FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                  WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                         (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                         (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                         (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                         (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                         (C.IDCSTINTEREST = 'N')                AND
                                                         (C.IDCSTINTERNA  = 'S')                AND
                                                         (C.CDPRODUTO IS NULL);
                        OPEN C_CSTNULL;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END ELSE BEGIN
               SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
               FROM   CODSITUTRIB C, PRODUTO P
               WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                      (CDEMPRESA       = @P_EMPRESA)         AND
                      (CDTIPOOPER      = @P_TIPOOPER)        AND
                      (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                      (C.CDPRODUTO     = P.CDPRODUTO)        AND
                      (C.IDCSTINTEREST = 'N')                AND
                      (C.IDCSTINTERNA  = 'S')                AND
                      (CDGRUPOFISC IS NULL)                  AND
                      (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD), @P_CDARVPROD),@P_CDARVPROD) = 1);
               IF NOT(@V_CDARVPROD IS NULL) BEGIN
                  DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                           FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                LEFT JOIN PRODUTO P ON(C.CDPRODUTO = P.CDPRODUTO)
                                           WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                  (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                  (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                  (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                  (C.IDCSTINTEREST = 'N')                AND
                                                  (C.IDCSTINTERNA  = 'S')                AND
                                                  (C.CDGRUPOFISC IS NULL)                AND
                                                  (P.CDARVPROD     = @V_CDARVPROD);
                     OPEN C_CST;
                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                               @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                               @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                               @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                               @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                               @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                          FROM CODSITUTRIBNFE CO, IMPOSTO IM
                         WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                               CO.NRINCIDCST = @V_NRINCIDCST AND
                               CO.CDIMPOSTO  = @P_CDIMPOSTO;
                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                  END;
                  CLOSE C_CST;
                  DEALLOCATE C_CST;
               END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                  DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                               FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                               WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                      (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                      (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                      (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                      (C.IDCSTINTEREST = 'N')                AND
                                                      (C.IDCSTINTERNA  = 'S')                AND
                                                      (C.CDGRUPOFISC IS NULL)                AND
                                                      (C.CDPRODUTO IS NULL);
                     OPEN C_CSTNULL;
                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                               @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                               @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                               @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                               @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                               @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                          FROM CODSITUTRIBNFE CO, IMPOSTO IM
                         WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                               CO.NRINCIDCST = @V_NRINCIDCST AND
                               CO.CDIMPOSTO  = @P_CDIMPOSTO;
                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                  END;
                  CLOSE C_CSTNULL;
                  DEALLOCATE C_CSTNULL;
               END;
            END;
         END ELSE BEGIN
            IF @P_CDARVPROD IS NULL BEGIN
               SELECT @V_CONTINTEREST = COUNT(*)
                 FROM CODSITUTRIB C
                WHERE (IDENTSAICST     = @P_ENTSAICST)
                  AND (CDEMPRESA       = @P_EMPRESA)
                  AND (CDTIPOOPER      = @P_TIPOOPER)
                  AND (CDINSCESTA      = RTRIM(@P_INSCESTA))
                  AND (C.IDCSTINTEREST = 'S')
                  AND (C.IDCSTINTERNA  = 'N')
                  AND (C.CDPRODUTO IS NULL);
            END ELSE BEGIN
               SELECT @V_CONTINTEREST = COUNT(*)
                 FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (P.CDPRODUTO = C.CDPRODUTO)
                WHERE (IDENTSAICST     = @P_ENTSAICST)
                  AND (CDEMPRESA       = @P_EMPRESA)
                  AND (CDTIPOOPER      = @P_TIPOOPER)
                  AND (CDINSCESTA      = RTRIM(@P_INSCESTA))
                  AND (C.IDCSTINTEREST = 'S')
                  AND (C.IDCSTINTERNA  = 'N')
                  AND (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD), @P_CDARVPROD),@P_CDARVPROD) = 1);
            END;
            IF @V_CONTINTEREST > 0 BEGIN
               IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM   CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                         (CDEMPRESA       = @P_EMPRESA)         AND
                         (CDTIPOOPER      = @P_TIPOOPER)        AND
                         (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                         (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                         (C.IDCSTINTEREST = 'S')                AND
                         (C.IDCSTINTERNA  = 'N')                AND
                         (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD), @P_CDARVPROD) = 1);

                  IF @V_CONTADOR > 0 BEGIN
                     IF NOT(@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                 FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                      LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                                                 WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                        (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                        (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                        (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                        (C.IDCSTINTEREST = 'S')                AND
                                                        (C.IDCSTINTERNA  = 'N')                AND
                                                        (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                        (P.CDARVPROD     = @V_CDARVPROD);

                           OPEN C_CST;
                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                     @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                     @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                     @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                     @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                     @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                                FROM CODSITUTRIBNFE CO, IMPOSTO IM
                               WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                     CO.NRINCIDCST = @V_NRINCIDCST AND
                                     CO.CDIMPOSTO  = @P_CDIMPOSTO;
                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        END;
                        CLOSE C_CST;
                        DEALLOCATE C_CST;
                     END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                     FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                     WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                            (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                            (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                            (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                            (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                            (C.IDCSTINTEREST = 'S')                AND
                                                            (C.IDCSTINTERNA  = 'N')                AND
                                                            (C.CDPRODUTO IS NULL);
                           OPEN C_CSTNULL;
                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                     @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                     @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                     @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                     @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                     @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                                FROM CODSITUTRIBNFE CO, IMPOSTO IM
                               WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                     CO.NRINCIDCST = @V_NRINCIDCST AND
                                     CO.CDIMPOSTO  = @P_CDIMPOSTO;
                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        END;
                        CLOSE C_CSTNULL;
                        DEALLOCATE C_CSTNULL;
                     END;
                  END;
               END ELSE BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM   CODSITUTRIB C, PRODUTO P
                  WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                         (CDEMPRESA       = @P_EMPRESA)         AND
                         (CDTIPOOPER      = @P_TIPOOPER)        AND
                         (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                         (C.CDPRODUTO     = P.CDPRODUTO)        AND
                         (C.IDCSTINTEREST = 'S')                AND
                         (C.IDCSTINTERNA  = 'N')                AND
                         (CDGRUPOFISC IS NULL)                  AND
                         (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD), @P_CDARVPROD),@P_CDARVPROD) = 1);
                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                              FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                   LEFT JOIN PRODUTO P ON(C.CDPRODUTO = P.CDPRODUTO)
                                              WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                     (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                     (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                     (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                     (C.IDCSTINTEREST = 'S')                AND
                                                     (C.IDCSTINTERNA  = 'N')                AND
                                                     (P.CDARVPROD     = @V_CDARVPROD)       AND
                                                     (C.CDGRUPOFISC IS NULL);
                        OPEN C_CST;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                  FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                  WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                         (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                         (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                         (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                         (C.IDCSTINTEREST = 'S')                AND
                                                         (C.IDCSTINTERNA  = 'N')                AND
                                                         (C.CDGRUPOFISC IS NULL)                AND
                                                         (C.CDPRODUTO IS NULL);
                        OPEN C_CSTNULL;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END
            ELSE BEGIN
               IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM   CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                         (CDEMPRESA       = @P_EMPRESA)         AND
                         (CDTIPOOPER      = @P_TIPOOPER)        AND
                         (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                         (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                         (C.IDCSTINTEREST = 'N')                AND
                         (C.IDCSTINTERNA  = 'N')                AND
                         (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD), @P_CDARVPROD) = 1);

                  IF @V_CONTADOR > 0 BEGIN
                     IF NOT(@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                 FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                      LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                                                 WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                        (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                        (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                        (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                        (C.IDCSTINTEREST = 'N')                AND
                                                        (C.IDCSTINTERNA  = 'N')                AND
                                                        (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                        (P.CDARVPROD     = @V_CDARVPROD);

                           OPEN C_CST;
                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                     @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                     @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                     @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                     @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                     @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                                FROM CODSITUTRIBNFE CO, IMPOSTO IM
                               WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                     CO.NRINCIDCST = @V_NRINCIDCST AND
                                     CO.CDIMPOSTO  = @P_CDIMPOSTO;
                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        END;
                        CLOSE C_CST;
                        DEALLOCATE C_CST;
                     END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                     FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                     WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                            (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                            (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                            (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                            (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                            (C.IDCSTINTEREST = 'N')                AND
                                                            (C.IDCSTINTERNA  = 'N')                AND
                                                            (C.CDPRODUTO IS NULL);
                           OPEN C_CSTNULL;
                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                     @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                     @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                     @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                     @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                     @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                                FROM CODSITUTRIBNFE CO, IMPOSTO IM
                               WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                     CO.NRINCIDCST = @V_NRINCIDCST AND
                                     CO.CDIMPOSTO  = @P_CDIMPOSTO;
                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        END;
                        CLOSE C_CSTNULL;
                        DEALLOCATE C_CSTNULL;
                     END;
                  END;
               END ELSE BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM   CODSITUTRIB C, PRODUTO P
                  WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                         (CDEMPRESA       = @P_EMPRESA)         AND
                         (CDTIPOOPER      = @P_TIPOOPER)        AND
                         (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                         (C.CDPRODUTO     = P.CDPRODUTO)        AND
                         (C.IDCSTINTEREST = 'N')                AND
                         (C.IDCSTINTERNA  = 'N')                AND
                         (CDGRUPOFISC IS NULL)                  AND
                         (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD), @P_CDARVPROD),@P_CDARVPROD) = 1);
                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                              FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                   LEFT JOIN PRODUTO P ON(C.CDPRODUTO = P.CDPRODUTO)
                                              WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                     (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                     (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                     (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                     (C.IDCSTINTEREST = 'N')                AND
                                                     (C.IDCSTINTERNA  = 'N')                AND
                                                     (P.CDARVPROD     = @V_CDARVPROD)       AND
                                                     (C.CDGRUPOFISC IS NULL);
                        OPEN C_CST;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                  FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                  WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                         (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                         (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                         (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                         (C.IDCSTINTEREST = 'N')                AND
                                                         (C.IDCSTINTERNA  = 'N')                AND
                                                         (C.CDGRUPOFISC IS NULL)                AND
                                                         (C.CDPRODUTO IS NULL);
                        OPEN C_CSTNULL;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END;
         END;
      END ELSE BEGIN
         IF (@P_IDCSTINTEREST = 'S') BEGIN
            IF @P_CDARVPROD IS NULL BEGIN
               SELECT @V_CONTINTEREST = COUNT(*)
                 FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                      (CDEMPRESA       = @P_EMPRESA)         AND
                      (CDTIPOOPER      = @P_TIPOOPER)        AND
                      (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                      (C.IDCSTINTEREST = 'S')                AND
                      (C.IDCSTINTERNA  = 'N')                AND
                      (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);
            END
            ELSE BEGIN
               SELECT @V_CONTINTEREST = COUNT(*)
                 FROM CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                WHERE (IDENTSAICST     = @P_ENTSAICST)       AND
                      (CDEMPRESA       = @P_EMPRESA)         AND
                      (CDTIPOOPER      = @P_TIPOOPER)        AND
                      (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                      (C.IDCSTINTEREST = 'S')                AND
                      (C.IDCSTINTERNA  = 'N')                AND
                      (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD),@P_CDARVPROD) = 1);
            END;
            IF @V_CONTINTEREST > 0 BEGIN
               IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM   CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                         (CDEMPRESA       = @P_EMPRESA)         AND
                         (CDTIPOOPER      = @P_TIPOOPER)        AND
                         (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                         (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                         (C.IDCSTINTEREST = 'S')                AND
                         (C.IDCSTINTERNA  = 'N')                AND
                         (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD), @P_CDARVPROD) = 1);

                  IF @V_CONTADOR > 0 BEGIN
                     IF NOT(@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                 FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                      LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                                                 WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                        (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                        (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                        (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                        (C.IDCSTINTEREST = 'S')                AND
                                                        (C.IDCSTINTERNA  = 'N')                AND
                                                        (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                        (P.CDARVPROD     = @V_CDARVPROD);

                           OPEN C_CST;
                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                     @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                     @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                     @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                     @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                     @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                                FROM CODSITUTRIBNFE CO, IMPOSTO IM
                               WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                     CO.NRINCIDCST = @V_NRINCIDCST AND
                                     CO.CDIMPOSTO  = @P_CDIMPOSTO;
                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        END;
                        CLOSE C_CST;
                        DEALLOCATE C_CST;
                     END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                     FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                     WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                            (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                            (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                            (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                            (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                            (C.IDCSTINTEREST = 'S')                AND
                                                            (C.IDCSTINTERNA  = 'N')                AND
                                                            (C.CDPRODUTO IS NULL);
                           OPEN C_CSTNULL;
                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                     @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                     @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                     @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                     @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                     @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                                FROM CODSITUTRIBNFE CO, IMPOSTO IM
                               WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                     CO.NRINCIDCST = @V_NRINCIDCST AND
                                     CO.CDIMPOSTO  = @P_CDIMPOSTO;
                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        END;
                        CLOSE C_CSTNULL;
                        DEALLOCATE C_CSTNULL;
                     END;
                  END;
               END ELSE BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM   CODSITUTRIB C, PRODUTO P
                  WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                         (CDEMPRESA       = @P_EMPRESA)         AND
                         (CDTIPOOPER      = @P_TIPOOPER)        AND
                         (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                         (C.CDPRODUTO     = P.CDPRODUTO)        AND
                         (C.IDCSTINTEREST = 'S')                AND
                         (C.IDCSTINTERNA  = 'N')                AND
                         (CDGRUPOFISC IS NULL)                  AND
                         (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD), @P_CDARVPROD),@P_CDARVPROD) = 1);
                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                              FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                   LEFT JOIN PRODUTO P ON(C.CDPRODUTO = P.CDPRODUTO)
                                              WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                     (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                     (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                     (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                     (C.IDCSTINTEREST = 'S')                AND
                                                     (C.IDCSTINTERNA  = 'N')                AND
                                                     (P.CDARVPROD     = @V_CDARVPROD)       AND
                                                     (C.CDGRUPOFISC IS NULL);
                        OPEN C_CST;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                  FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                  WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                         (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                         (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                         (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                         (C.IDCSTINTEREST = 'S')                AND
                                                         (C.IDCSTINTERNA  = 'N')                AND
                                                         (C.CDGRUPOFISC IS NULL)                AND
                                                         (C.CDPRODUTO IS NULL);
                        OPEN C_CSTNULL;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END
            ELSE BEGIN
               IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM   CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                  WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                         (CDEMPRESA       = @P_EMPRESA)         AND
                         (CDTIPOOPER      = @P_TIPOOPER)        AND
                         (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                         (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                         (C.IDCSTINTEREST = 'N')                AND
                         (C.IDCSTINTERNA  = 'N')                AND
                         (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD), @P_CDARVPROD) = 1);

                  IF @V_CONTADOR > 0 BEGIN
                     IF NOT(@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                 FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                      LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                                                 WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                        (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                        (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                        (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                        (C.IDCSTINTEREST = 'N')                AND
                                                        (C.IDCSTINTERNA  = 'N')                AND
                                                        (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                        (P.CDARVPROD     = @V_CDARVPROD);

                           OPEN C_CST;
                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                     @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                     @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                     @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                     @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                     @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                                FROM CODSITUTRIBNFE CO, IMPOSTO IM
                               WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                     CO.NRINCIDCST = @V_NRINCIDCST AND
                                     CO.CDIMPOSTO  = @P_CDIMPOSTO;
                           FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        END;
                        CLOSE C_CST;
                        DEALLOCATE C_CST;
                     END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                        DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                     FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                     WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                            (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                            (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                            (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                            (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                            (C.IDCSTINTEREST = 'N')                AND
                                                            (C.IDCSTINTERNA  = 'N')                AND
                                                            (C.CDPRODUTO IS NULL);
                           OPEN C_CSTNULL;
                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                     @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                     @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                     @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                     @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                     @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                                FROM CODSITUTRIBNFE CO, IMPOSTO IM
                               WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                     CO.NRINCIDCST = @V_NRINCIDCST AND
                                     CO.CDIMPOSTO  = @P_CDIMPOSTO;
                           FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        END;
                        CLOSE C_CSTNULL;
                        DEALLOCATE C_CSTNULL;
                     END;
                  END;
               END ELSE BEGIN
                  SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
                  FROM   CODSITUTRIB C, PRODUTO P
                  WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                         (CDEMPRESA       = @P_EMPRESA)         AND
                         (CDTIPOOPER      = @P_TIPOOPER)        AND
                         (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                         (C.CDPRODUTO     = P.CDPRODUTO)        AND
                         (C.IDCSTINTEREST = 'N')                AND
                         (C.IDCSTINTERNA  = 'N')                AND
                         (CDGRUPOFISC IS NULL)                  AND
                         (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD), @P_CDARVPROD),@P_CDARVPROD) = 1);
                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                              FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                   LEFT JOIN PRODUTO P ON(C.CDPRODUTO = P.CDPRODUTO)
                                              WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                     (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                     (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                     (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                     (C.IDCSTINTEREST = 'N')                AND
                                                     (C.IDCSTINTERNA  = 'N')                AND
                                                     (P.CDARVPROD     = @V_CDARVPROD)       AND
                                                     (C.CDGRUPOFISC IS NULL);
                        OPEN C_CST;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                  FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                  WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                         (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                         (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                         (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                         (C.IDCSTINTEREST = 'N')                AND
                                                         (C.IDCSTINTERNA  = 'N')                AND
                                                         (C.CDGRUPOFISC IS NULL)                AND
                                                         (C.CDPRODUTO IS NULL);
                        OPEN C_CSTNULL;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END;
         END ELSE BEGIN
            IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
               SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
               FROM   CODSITUTRIB C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
               WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                      (CDEMPRESA       = @P_EMPRESA)         AND
                      (CDTIPOOPER      = @P_TIPOOPER)        AND
                      (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                      (CDGRUPOFISC     = @P_CDGRUPOFISC)     AND
                      (C.IDCSTINTEREST = 'N')                AND
                      (C.IDCSTINTERNA  = 'N')                AND
                      (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD), @P_CDARVPROD) = 1);

               IF @V_CONTADOR > 0 BEGIN
                  IF NOT(@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                              FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                   LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                                              WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                     (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                     (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                     (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                     (C.IDCSTINTEREST = 'N')                AND
                                                     (C.IDCSTINTERNA  = 'N')                AND
                                                     (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                     (P.CDARVPROD     = @V_CDARVPROD);

                        OPEN C_CST;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CST;
                     DEALLOCATE C_CST;
                  END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                     DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                                  FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                  WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                         (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                         (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                         (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                         (C.CDGRUPOFISC   = @P_CDGRUPOFISC)     AND
                                                         (C.IDCSTINTEREST = 'N')                AND
                                                         (C.IDCSTINTERNA  = 'N')                AND
                                                         (C.CDPRODUTO IS NULL);
                        OPEN C_CSTNULL;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                                  @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                                  @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                                  @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                                  @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                                  @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                             FROM CODSITUTRIBNFE CO, IMPOSTO IM
                            WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                                  CO.NRINCIDCST = @V_NRINCIDCST AND
                                  CO.CDIMPOSTO  = @P_CDIMPOSTO;
                        FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     END;
                     CLOSE C_CSTNULL;
                     DEALLOCATE C_CSTNULL;
                  END;
               END;
            END ELSE BEGIN
               SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
               FROM   CODSITUTRIB C, PRODUTO P
               WHERE  (IDENTSAICST     = @P_ENTSAICST)       AND
                      (CDEMPRESA       = @P_EMPRESA)         AND
                      (CDTIPOOPER      = @P_TIPOOPER)        AND
                      (CDINSCESTA      = RTRIM(@P_INSCESTA)) AND
                      (C.CDPRODUTO     = P.CDPRODUTO)        AND
                      (C.IDCSTINTEREST = 'N')                AND
                      (C.IDCSTINTERNA  = 'N')                AND
                      (CDGRUPOFISC IS NULL)                  AND
                      (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD), @P_CDARVPROD),@P_CDARVPROD) = 1);
               IF NOT(@V_CDARVPROD IS NULL) BEGIN
                  DECLARE C_CST CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                           FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                                                LEFT JOIN PRODUTO P ON(C.CDPRODUTO = P.CDPRODUTO)
                                           WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                  (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                  (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                  (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                  (C.IDCSTINTEREST = 'N')                AND
                                                  (C.IDCSTINTERNA  = 'N')                AND
                                                  (P.CDARVPROD     = @V_CDARVPROD)       AND
                                                  (C.CDGRUPOFISC IS NULL);
                     OPEN C_CST;
                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                               @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                               @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                               @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                               @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                               @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                          FROM CODSITUTRIBNFE CO, IMPOSTO IM
                         WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                               CO.NRINCIDCST = @V_NRINCIDCST AND
                               CO.CDIMPOSTO  = @P_CDIMPOSTO;
                     FETCH NEXT FROM C_CST INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                  END;
                  CLOSE C_CST;
                  DEALLOCATE C_CST;
               END ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                  DECLARE C_CSTNULL CURSOR FOR SELECT CDSITUTRIB, DSMENSCST, C.NRINCIDCST
                                               FROM   CODSITUTRIB C LEFT JOIN MENSCST M ON (C.NRINCIDCST = M.NRINCIDCST)
                                               WHERE  (C.IDENTSAICST   = @P_ENTSAICST)       AND
                                                      (C.CDEMPRESA     = @P_EMPRESA)         AND
                                                      (C.CDTIPOOPER    = @P_TIPOOPER)        AND
                                                      (C.CDINSCESTA    = RTRIM(@P_INSCESTA)) AND
                                                      (C.IDCSTINTEREST = 'N')                AND
                                                      (C.IDCSTINTERNA  = 'N')                AND
                                                      (C.CDGRUPOFISC IS NULL)                AND
                                                      (C.CDPRODUTO IS NULL);
                     OPEN C_CSTNULL;
                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        SELECT @V_CDSITUTRIBNFE   = CO.CDSITUTRIBNFE,
                               @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN CO.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                               @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN CO.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                               @V_CDTPCRPICOSTNFE = CO.CDTPCRPICOSTNFE,
                               @V_CDNATUBCPCSTNFE = CO.CDNATUBCPCSTNFE,
                               @V_IDMOTIDESSTNFE  = CO.IDMOTIDESSTNFE
                          FROM CODSITUTRIBNFE CO, IMPOSTO IM
                         WHERE IM.CDIMPOSTO  = CO.CDIMPOSTO  AND
                               CO.NRINCIDCST = @V_NRINCIDCST AND
                               CO.CDIMPOSTO  = @P_CDIMPOSTO;
                     FETCH NEXT FROM C_CSTNULL INTO @V_CDSITUTRIB, @V_DSMENSCST, @V_NRINCIDCST;
                  END;
                  CLOSE C_CSTNULL;
                  DEALLOCATE C_CSTNULL;
               END;
            END;
         END;
      END;
      ----------------------------------------------------------------------------------
      IF (@V_CDSITUTRIBNFE IS NULL) BEGIN
         SET @V_CONTADOR = 0;
         IF (@P_CDGRUPOFISC IS NOT NULL) BEGIN
            SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
            FROM   CODSITUTRIBNFE C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
            WHERE  (IDENTSAICSTNFE  = @P_ENTSAICST)   AND
                   (CDEMPRESA       = @P_EMPRESA)     AND
                   (CDTIPOOPER      = @P_TIPOOPER)    AND
                   (CDGRUPOFISC     = @P_CDGRUPOFISC) AND
                   (CDIMPOSTO       = @P_CDIMPOSTO)   AND
                   (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD), @P_CDARVPROD) = 1);
            IF (@V_CONTADOR > 0) BEGIN
               IF NOT(@V_CDARVPROD IS NULL) BEGIN
                  SELECT @V_CDSITUTRIBNFE   = CDSITUTRIBNFE,
                         @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN C.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                         @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN C.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                         @V_CDTPCRPICOSTNFE = CDTPCRPICOSTNFE,
                         @V_CDNATUBCPCSTNFE = CDNATUBCPCSTNFE,
                         @V_IDMOTIDESSTNFE  = IDMOTIDESSTNFE
                    FROM IMPOSTO IM, CODSITUTRIBNFE C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                   WHERE (IM.CDIMPOSTO     = C.CDIMPOSTO)    AND
                         (C.IDENTSAICSTNFE = @P_ENTSAICST)   AND
                         (C.CDEMPRESA      = @P_EMPRESA)     AND
                         (C.CDTIPOOPER     = @P_TIPOOPER)    AND
                         (C.CDGRUPOFISC    = @P_CDGRUPOFISC) AND
                         (C.CDIMPOSTO      = @P_CDIMPOSTO)   AND
                         (P.CDARVPROD      = @V_CDARVPROD);
               END
               ELSE IF (@V_CDARVPROD IS NULL) BEGIN
                  SELECT @V_CDSITUTRIBNFE   = CDSITUTRIBNFE,
                         @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN C.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                         @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN C.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                         @V_CDTPCRPICOSTNFE = CDTPCRPICOSTNFE,
                         @V_CDNATUBCPCSTNFE = CDNATUBCPCSTNFE,
                         @V_IDMOTIDESSTNFE  = IDMOTIDESSTNFE
                    FROM IMPOSTO IM, CODSITUTRIBNFE C
                   WHERE (IM.CDIMPOSTO     = C.CDIMPOSTO)    AND
                         (C.IDENTSAICSTNFE = @P_ENTSAICST)   AND
                         (C.CDEMPRESA      = @P_EMPRESA)     AND
                         (C.CDTIPOOPER     = @P_TIPOOPER)    AND
                         (C.CDGRUPOFISC    = @P_CDGRUPOFISC) AND
                         (C.CDIMPOSTO      = @P_CDIMPOSTO)   AND
                         (C.CDPRODUTO IS NULL);
               END;
            END;
         END
         ELSE BEGIN
            SELECT @V_CDARVPROD = MAX(P.CDARVPROD), @V_CONTADOR = COUNT(*)
            FROM   CODSITUTRIBNFE C, PRODUTO P
            WHERE  (IDENTSAICSTNFE = @P_ENTSAICST) AND
                   (CDEMPRESA      = @P_EMPRESA)   AND
                   (CDTIPOOPER     = @P_TIPOOPER)  AND
                   (CDIMPOSTO      = @P_CDIMPOSTO) AND
                   (C.CDPRODUTO    = P.CDPRODUTO)  AND
                   (CDGRUPOFISC IS NULL)           AND
                   (CHARINDEX(ISNULL(RTRIM(P.CDARVPROD),@P_CDARVPROD), @P_CDARVPROD) = 1);
            IF NOT(@V_CDARVPROD IS NULL) BEGIN
               SELECT @V_CDSITUTRIBNFE   = CDSITUTRIBNFE,
                      @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN C.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                      @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN C.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                      @V_CDTPCRPICOSTNFE = CDTPCRPICOSTNFE,
                      @V_CDNATUBCPCSTNFE = CDNATUBCPCSTNFE,
                      @V_IDMOTIDESSTNFE  = IDMOTIDESSTNFE
                 FROM IMPOSTO IM, CODSITUTRIBNFE C LEFT JOIN PRODUTO P ON (C.CDPRODUTO = P.CDPRODUTO)
                WHERE (IM.CDIMPOSTO     = C.CDIMPOSTO)    AND
                      (C.IDENTSAICSTNFE = @P_ENTSAICST)   AND
                      (C.CDEMPRESA      = @P_EMPRESA)     AND
                      (C.CDTIPOOPER     = @P_TIPOOPER)    AND
                      (C.CDIMPOSTO      = @P_CDIMPOSTO)   AND
                      (P.CDARVPROD      = @V_CDARVPROD)   AND
                      (C.CDGRUPOFISC IS NULL);
            END
            ELSE IF (@V_CDARVPROD IS NULL) BEGIN
               SELECT @V_CDSITUTRIBNFE   = CDSITUTRIBNFE,
                      @V_IDMODBCNFE      = CASE IM.IDMODBCNFE   WHEN '9' THEN C.IDMODBCNFE   ELSE IM.IDMODBCNFE   END,
                      @V_IDMODBCSTNFE    = CASE IM.IDMODBCSTNFE WHEN '9' THEN C.IDMODBCSTNFE ELSE IM.IDMODBCSTNFE END,
                      @V_CDTPCRPICOSTNFE = CDTPCRPICOSTNFE,
                      @V_CDNATUBCPCSTNFE = CDNATUBCPCSTNFE,
                      @V_IDMOTIDESSTNFE  = IDMOTIDESSTNFE
                 FROM IMPOSTO IM, CODSITUTRIBNFE C
                WHERE (IM.CDIMPOSTO     = C.CDIMPOSTO)    AND
                      (C.IDENTSAICSTNFE = @P_ENTSAICST)   AND
                      (C.CDEMPRESA      = @P_EMPRESA)     AND
                      (C.CDTIPOOPER     = @P_TIPOOPER)    AND
                      (C.CDIMPOSTO      = @P_CDIMPOSTO)   AND
                      (C.CDPRODUTO   IS NULL)             AND
                      (C.CDGRUPOFISC IS NULL);
            END;
         END;
      END;
   END;

   IF @V_IDMOTIDESSTNFE IS NULL BEGIN
      SET @V_IDMOTIDESSTNFE = '9';
   END;
   SET @P_CDSITTRIBTMP    = @V_CDSITUTRIBNFE;
   SET @P_IDMODBCNFE      = @V_IDMODBCNFE;
   SET @P_IDMODBCSTNFE    = @V_IDMODBCSTNFE;
   SET @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE;
   SET @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE;
   SET @P_IDMOTIDESSTNFE  = @V_IDMOTIDESSTNFE;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CONSULTA_CST_NFE','6.05.xxx';
GO
